#
# spec file for package eiciel
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _libnautilus_extensiondir %(pkg-config --variable extensiondir libnautilus-extension)
Name:           eiciel
Version:        0.9.9
Release:        7.10
Summary:        GNOME ACL viewer and editor
License:        GPL-2.0+
Group:          System/GUI/GNOME
Url:            http://rofi.roger-ferrer.org/eiciel/
Source:         http://rofi.roger-ferrer.org/eiciel/download/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  translation-update-upstream
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?favor_gtk2}
BuildRequires:  pkgconfig(gtkmm-2.4)
BuildRequires:  pkgconfig(libnautilus-extension) < 2.90
%else
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(libnautilus-extension) >= 3.0.0
%endif

%description
Eiciel allows you to visually edit file ACL entries. You can add and
remove users and groups who will be granted permissions through the
graphical interface

%package -n nautilus-eiciel
Summary:        Nautilus ACL viewer and editor extension
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Supplements:    packageand(eiciel:nautilus)

%description -n nautilus-eiciel
A Nautilus extension that allows viewing and editing ACL permissions.

%lang_package

%prep
%setup -q
translation-update-upstream

%build
%configure \
        --disable-static \
%if 0%{?favor_gtk2}
        --with-gnome-version=2
%else
        --with-gnome-version=3
%endif
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
rm %{buildroot}%{_datadir}/applications/*.desktop
%fdupes -s %{buildroot}

%files
%defattr (-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%{_bindir}/eiciel
%doc %{_mandir}/man1/eiciel.1.gz
%dir %{_datadir}/appdata
%{_datadir}/appdata/eiciel.appdata.xml
%{_datadir}/eiciel/
%{_datadir}/icons/hicolor/*/apps/eiciel.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n nautilus-eiciel
%defattr (-, root, root)
%{_libnautilus_extensiondir}/libeiciel-nautilus.so

%changelog
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 0.9.9:
  + A new filter box
  + Several changes in the UI to make it a bit more consistent with
    the GNOME HIG.
  + Help has been ported from DocBook to Mallard.
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 0.9.8.3:
  + This version does not include any new feature but better
    integration with PackageKit.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Fix for ineffective permissions not correctly rendered in
    GNOME 3.
- Remove hack to remove executable bit from Authors: fixed
  upstream.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Jun  1 2011 vuntz@opensuse.org
- Do not fail to build if %%gtk2_favor is not defined: just use
  0%%{?gtk2_favor}.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 0.9.8.1:
  + Allow building against GNOME 3 libraries.
- Pass --disable-static to configure
- Remove --with-nautilus-extensions-dir from configure: it is
  correctly detected based on the libnautilus-extension.pc file.
- Build based on gtk2_favor either for gnome2 or for gnome3
- Add BuildRequires for gnome 3 build:
  + pkgconfig(gtkmm-3.0)
  + pkgconfig(libnautilus-extension) => 3.0.0
- Change BuildRequires for gnome2 build to pkgconfig()-style:
  + Old ones: gtkmm24-devel, libnautilus-devel
  + New ones: gtkmm-2.4, libnautilus.extension
* Mon Feb 14 2011 sbrabec@suse.cz
- Translations migrated to translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 0.9.8:
  + Various bugfixes
  + Translation updates.
- Drop unused patch: eiciel-library-packaging.patch
- Supplement nautilus and eiciel with nautilus-eiciel.
- AUTHORS is non-executable.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.9.7:
  + This is a catch-up with all the Debian patches
  + Source code has been translated to english to facilitate the
    start for new contributors
* Mon Mar  9 2009 vuntz@novell.com
- Drop eiciel-gcc4.3-fixes.patch: it's not used, and if it's not
  needed anymore, we can drop it.
- Remove AutoReqProv: it's default now.
- Remove check for old version of openSUSE.
- Remove unneeded BuildRequires: gnome-desktop-devel, gnutls-devel,
  libglade2-devel, libgnomeprintui-devel, libwnck-devel,
  perl-XML-Parser, update-desktop-files.
- Add BuildRequires to fix build: libgnomeui-devel.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Updated translations.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.9.6.1:
  + Minor bugfixes.
* Tue Mar  4 2008 jpr@suse.de
- Update to 0.9.5.1
  * Make help launching more robust
* Wed Nov  7 2007 maw@suse.de
- Add eiciel-gcc4.3-fixes.patch.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Aug  9 2007 maw@suse.de
- Fix up the -lang subpackage.
* Tue Aug  7 2007 mauro@suse.de
- Split out a -lang subpackage
- Add %%fdupes stuff
* Wed Jan 31 2007 jhargadon@suse.de
- added eiciel to Requires of nautilus-eiciel subpackage (#239732)
- specfile cleanup
* Fri Jan 26 2007 jhargadon@suse.de
- fixed a shared library packaging bug (#238541)
* Thu Jan 25 2007 ro@suse.de
- GNOME moved to /usr
* Wed Dec 13 2006 jpr@suse.de
- Update to 0.9.4, bugfix release to improve compatibility with
  filesystems implemented using FUSE
* Wed Sep 20 2006 jpr@suse.de
- Fix 64 bit builds by ensure that the nautilus extensions are
  searched for in %%{_lib} not lib
* Mon Aug 28 2006 jpr@suse.de
- Eiciel a plugin for nautilus to handle posix ACLs
